import 'package:flutter/material.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:flutter_query/flutter_query.dart';
import 'package:flutter_query/src/query_cache.dart';
import 'package:flutter_test/flutter_test.dart';

void main() {
  testWidgets('useQuery', (tester) async {
    var passed = false;

    await tester.pumpFrames(
      QueryCacheProvider(
        child: HookBuilder(
          builder: (context) {
            final result = useQuery(
              'data',
              () => Future.delayed(Duration(seconds: 1)).then((d) => 'Hello!'),
              onSuccess: (data) {
                print('Success!');
              },
              onError: (err) {
                print('Shouldnt hit here!');
              },
            );
            if (result.isSuccess && result.data == 'Hello!') {
              passed = true;
            }
            return Container();
          },
        ),
      ),
      Duration(seconds: 5),
    );

    expect(passed, true);
  });

  testWidgets('useInfiniteQuery', (tester) async {
    var passed = false;
    var index = 0;

    await tester.pumpFrames(
      QueryCacheProvider(
        child: HookBuilder(
          builder: (context) {
            final result = useInfiniteQuery(
              'data',
              (page) {
                final value =
                    page > 0 ? List<String>.empty() : ['Test', 'Test', 'Test'];
                return Future<List<String>>.value(value);
              },
              getFetchMore: (latestPage) => index++,
            );
            if (!result.canFetchMore && !result.isLoading) {
              passed = true;
            }
            if (result.isSuccess && result.canFetchMore) {
              result.fetchMore();
            }
            return Container();
          },
        ),
      ),
      Duration(seconds: 5),
    );

    expect(passed, true);
  });
}
